import requests

version = "1.0.1"

class Client:
	def __init__(self, endpoint, client_id, client_secret, host_domain, logout_path="/", redirect_path="/oauth"):
		self.endpoint = endpoint
		self.client_id = client_id
		self.client_secret = client_secret
		self.host = host_domain
		self.logout_path = logout_path
		self.redirect_path = redirect_path

	@property
	def loginUrl(self):
		return 'https://' + self.endpoint + '/login?client_id=' + self.client_id + "&redirect_uri=https://" + self.host + self.redirect_path + "&response_type=code"

	@property
	def registerUrl(self):
		return 'https://' + self.endpoint + '/signup?client_id=' + self.client_id + "&redirect_uri=https://" + self.host + self.redirect_path + "&response_type=code"

	@property
	def logoutUrl(self):
		return 'https://' + self.endpoint + '/logout?client_id=' + self.client_id + "&logout_uri=https://" + self.host + self.logout_path

	def get_token(self, code):
		r = requests.post('https://' + self.endpoint + '/oauth2/token', auth=(self.client_id, self.client_secret),
			data = {'code':code, 'grant_type':'authorization_code', 'redirect_uri': "https://" + self.host + self.redirect_path })
		return r.json()['access_token']

class User:
	def __init__(self, client, token = None):
		self.data = {}
		self.token = token
		self.client = client
		self.reload()

	def is_logged_in(self):
		self.reload()
		return 'username' in self.data

	def reload(self):
		if self.token:
			self.data = requests.post('https://' + self.client.endpoint + '/oauth2/userInfo', headers={'Authorization' :"Bearer " + self.token}).json()



import re 
from os import path

from setuptools import setup
from codecs import open

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

def read(*parts):
    return open(path.join(here, *parts), 'r').read()

def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^version = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")

setup(
    name='cognito-oauthtools',
    version=find_version('cognito_oauthtools','__init__.py'),
    description='Simple AWS Cognito client to simplify implementation',
    long_description=long_description,
    long_description_content_type="text/markdown",

    # The project's main homepage.
    url='https://github.com/josephbmanley/cognito-oauthtools',

    # Author details
    author='Joseph Manley',
    author_email='j@cloudsumu.com',

    # Choose your license
    license='GPL3.0',

    # See https://pypi.org/classifiers/
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8'
    ],
    keywords='AWS,Cognito,OAuth',
    packages=["cognito_oauthtools"],
    install_requires=['requests'],
    package_data={},
    entry_points={}
)
